process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0'
process.env.SUPPRESS_NO_CONFIG_WARNING = true

const httpMocks = require('node-mocks-http')
const fixtures = require('./../fixtures/fixtures')
const Model = require('./../helpers/Model')

const models = Model.build()

const { author, submittingAuthor } = fixtures.users
const { standardCollection } = fixtures.collections
const { authorTeam } = fixtures.teams
const deletePath = '../../routes/collectionsUsers/delete'

describe('Delete collections users route handler', () => {
  it('should return success when an author is deleted', async () => {
    const req = httpMocks.createRequest({})
    req.user = submittingAuthor.id
    req.params.collectionId = standardCollection.id
    req.params.userId = author.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)

    expect(res.statusCode).toBe(200)
    expect(authorTeam.members).not.toContain(author.id)
    expect(author.teams).not.toContain(authorTeam.id)
  })
  it('should return an error when the collection does not exist', async () => {
    const req = httpMocks.createRequest({})
    req.user = submittingAuthor.id
    req.params.collectionId = 'invalid-id'
    req.params.userId = author.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)

    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('item not found')
  })
  it('should return an error when the user does not exist', async () => {
    const req = httpMocks.createRequest({})
    req.user = submittingAuthor.id
    req.params.collectionId = standardCollection.id
    req.params.userId = 'invalid-id'
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)

    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('item not found')
  })
})
