import React from 'react'
import { th } from '@pubsweet/ui'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { withJournal } from 'xpub-journal'
import { replace } from 'react-router-redux'
import { compose, lifecycle } from 'recompose'

import { RootContainer, Title } from './FormItems'
import { reviewerDecline } from '../../redux/reviewers'
import { redirectToError } from '../utils'

const ReviewerDecline = ({ journal: { metadata: { email } } }) => (
  <RootContainer>
    <Title>Thank you for letting us know.</Title>
    <div>
      <Description>
        We hope you will review for Hindawi in the future. If you want any more
        information, or would like to submit a review for this article, then
        please contact us at{' '}
        <MailLink href={`mailto:${email}`} target="_blank">
          {email}
        </MailLink>.
      </Description>
    </div>
  </RootContainer>
)

export default compose(
  withJournal,
  connect(null, { reviewerDecline, replace }),
  lifecycle({
    componentDidMount() {
      const {
        collectionId,
        invitationId,
        invitationToken,
        reviewerDecline,
        replace,
      } = this.props
      reviewerDecline(invitationId, collectionId, invitationToken).catch(
        redirectToError(replace),
      )
    },
  }),
)(ReviewerDecline)

// #region styled-components
const MailLink = styled.a`
  color: ${th('colorPrimary')};

  &:visited {
    color: ${th('colorTextPlaceholder')};
  }
`

const Description = styled.span`
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`
// #endregion
